Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1854)

Unified Diff: chrome/browser/predictors/resource_prefetch_predictor.h

Issue 2227723002: predictors: Also track "no-cache" and "must-revalidate" resources. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/predictors/resource_prefetch_predictor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/predictors/resource_prefetch_predictor.h
diff --git a/chrome/browser/predictors/resource_prefetch_predictor.h b/chrome/browser/predictors/resource_prefetch_predictor.h
index 15768ecf565f81f3dc87005b2053d29eea206b67..252da51eb0f6c20cbb7a61b69abf7d9cfef067f3 100644
--- a/chrome/browser/predictors/resource_prefetch_predictor.h
+++ b/chrome/browser/predictors/resource_prefetch_predictor.h
@@ -66,8 +66,6 @@ class ResourcePrefetcherManager;
// * ResourcePrefetcher - Lives entirely on the IO thread, owned by the
// ResourcePrefetcherManager, and issues net::URLRequest to fetch resources.
//
-// TODO(shishir): Do speculative prefetching for https resources and/or https
-// main frame urls.
// TODO(zhenw): Currently only main frame requests/redirects/responses are
// recorded. Consider recording sub-frame responses independently or together
// with main frame.
@@ -187,8 +185,8 @@ class ResourcePrefetchPredictor
static bool IsHandledResourceType(content::ResourceType resource_type,
const std::string& mime_type);
- // Returns true if the request (should have a response in it) is cacheable.
- static bool IsCacheable(const net::URLRequest* request);
+ // Returns true if the request (should have a response in it) is "no-store".
+ static bool IsNoStore(const net::URLRequest* request);
// KeyedService methods override.
void Shutdown() override;
« no previous file with comments | « no previous file | chrome/browser/predictors/resource_prefetch_predictor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698